; (any text to the right of a semicolon is a comment)
;
; SONG DATA FILE
;
; This file contains all the data that makes up a song for
; the song player.  By editing this file, you can write your
; own music on the 2600!  The process involves writing patterns
; (which are at the bottom of this file) and then arranging them
; into a song.  After you write a pattern, you'll add it to the
; patternArray, and then can use it in one or both of the song
; pattern lists.
;
; The song format is not terribly easy (especially the
; pattern format) but once learned, it's not too hard to use.
; I can now write entire songs in just a few hours.  And the
; odd format will probably cause you to try things you wouldn't
; think of doing in a more traditional sequencer.  I find it's
; a lot of fun to write music on the 2600 and it has some very
; unique (and good) sounds, so I think it's worth beating the
; learning curve.
;
; It is nice to have a Synthcart when you're composing,
; mainly because it helps when you're trying to find notes.
; You should consider either acquiring a Synthcart or
; downloading the ROM for it.
;
; This file contains a very simple song.  For a much more complex
; song, see the marsong.h file.
;


;-------------------------------------------------------------
; Tempo
;-------------------------------------------------------------
; TEMPODELAY sets the song tempo.  Higher values mean a slower
; song.  1 is extremely fast and 10 is very slow.  You can set it
; higher than 10, but it will be extremely slow.  As you can tell,
; the tempo is currently only adjustable in very large increments.
; Future versions of the software will allow more precise tempo
; settings.  Note that TEMPODELAY must be against the left
; edge (no space or tab to the left.)

TEMPODELAY equ 3

;-------------------------------------------------------------
; Song Data
;-------------------------------------------------------------
; song1 and song2 are lists of patterns to be played
; out of the patternArray.
; Both song1 and song2 will be played simlutaneously 
; by the software, one on each of the two oscillators,
; so each song should be exactly the same length or you
; may have some problems!  
;
; Each number (after "byte")
; refers to a pattern in the patternArray, and 255
; indicates the end of the song.  Also, notice that
; the number convention is that 0 refers to the first
; pattern in patternArray, 2 refers to the second,
; 4 refers to the third, etc.
;
; "song1" and "song2" must be against the left
; edge, and each "byte" statement must have at
; least one space or tab to the left of it.  I
; have only put two pattern numbers on each line
; but you can put as many as you want (each number
; separated by a comma.)  A song cannot
; exceed 255 patterns.
;
; In my example song, it will play:
;
;   beat1, beat2, beat1, beat2
;
; on oscillator 1, and on oscillator 2 it will play:
;
;   hatMel1, hamMel1, hatMel2, hatMel2


song1
	byte 2, 8
	byte 2, 8

	byte 255

song2
	byte 6, 6
	byte 10, 10

	byte 255


;-------------------------------------------------------------
; Pattern List
;-------------------------------------------------------------
; patternArray is a list of the patterns you've created.
; You can name the patterns whatever you want.
; I always put a comment
; to the right with the pattern number so when I'm 
; writing the song (above) I can easily see the number
; of the pattern.  Remember, it starts with 0 and increases
; 2 for each pattern.  So if I added another pattern, it
; would be 12, then 14, and so on.  I usually make the
; first pattern an empty pattern called patternMute
; because in most songs I end up having one of the oscillators
; silent for a measure.
; You'll find data for each of these patterns below.
; Make sure the name in the patternArray matches the
; name below or you'll get an error.  The maximum
; number of patterns is 128.

patternArray
	word patternMute, beat1		; 0 2
	word hat, hatMel1			; 4 6
	word beat2, hatMel2			; 8 10



;-------------------------------------------------------------
; Pattern Data
;-------------------------------------------------------------
; This is probably the most difficult part to learn since
; the format is not very user friendly.  If you programmed
; beats for the Synthcart beat programming contest, this is
; pretty much the same format.
;
; It is very helpful if you reuse patterns you've written.
; Find one that's similar to what you need and modify it.
; 
; (way) below you'll find data for the patterns listed in the
; patternArray.  Each one has a name and is followed
; by 36 bytes of data.  Each of
; the first 32 numbers in the data set
; represents a 32nd note from the beginning of the measure
; to the end.  The four bytes after that determine
; which 32nd notes are accented (louder).
;
; Note that the percent sign means that you
; are entering a binary number.
;
;
; Note Encoding
; ----------------------------------------------------------
;
; The 32 note numbers are encoded with sound type and pitch.
; I put two 32nd notes per line like this:
;
;	byte %00111000, %00111000
;
; The first three bits (1's and  0's) determine the 
; sound type according to the following table:
;
; 000 Square
; 001 Bass  
; 010 Pitfall
; 011 Noise  
; 100 Buzz   
; 101 Lead   
; 110 Saw    
; 111 Engine 
;
; Note that different sound types have differnet
; tunings, so they don't all work together well.  Some sound
; type pairs that do work together are:
;
; Bass and Pitfall
;
; Square and Lead
;
; 
; "Noise" is good for drum beats.  :o)
;
;
; The remaining 5 bits determine the pitch.
;
; 11111 is a very low pitch
; 00001 us a very high pitch
; 00100 is somewhere in between
;
; (!) Note that 255 or %11111111 means no sound (a rest)
;
; Some examples:
;
; %00111100 = bass with a low pitch
; %10000010 = buzz sound with a high pitch
; %11100101 = engine sound with a medium pitch
; %11111111 = no sound
;
;
;
; The pitch on the Atari is not all on a musical scale,
; so you'll end up with some really out-of-tune stuff
; if you aren't careful.
; However I have made a list of pitches that do fall
; on a scale.
; If you have a Synthcart, these are the notes that
; are programmed in as the "Major Scale".
; 
;
;  29=11101 26=11010 23=10111 
;  19=10011 17=10001 15=01111
;  14=01110 11=01011  9=01001
;   4=00100  2=00010  1=00001
;
;
;
; Accent Encoding
; ----------------------------------------------------------
;
; The four numbers at the end of the pattern data 
; that look like this...
;  
;	byte #%10001000, #%10001000, #%10001000, #%10001000
;
; ...determine which notes are accented.  Good accents can 
; really make a pattern a lot better.  Notice there are 
; 32 bits, and conveniently they correspond to each of the 32
; notes.  The way I have it set up above, accents fall on each
; 8th note.  1 = accent (loud), 0 = no accent (no as loud)
; 
; To just make the whole beat quieter, use all zeros:
;
; byte #%00000000, #%00000000, #%00000000, #%00000000
;
; To make the whole beat louder:
;
; byte #%11111111, #%11111111, #%11111111, #%11111111
;
; Here's a strange accent pattern:
;
; byte #%10011001, #%11011011, #%10011001, #%10001111
;
;
;
;
; Patterns:


hatMel2
	byte %10111010, 255
	byte %10110001, 255
	byte %10101011, 255
	byte %10110001, 255

	byte %10111010, %10111010
	byte %10110001, 255
	byte %10100001, 255
	byte %10110001, 255

	byte %10111010, 255
	byte %10110001, 255
	byte %10101011, %10101011
	byte %10110001, 255

	byte %10111010, 255
	byte %10110001, 255
	byte %10100010, %10101011
	byte %10110001, 255

	byte #%00000000, #%00000000, #%00000000, #%00000000



hatMel1
	byte %10111101, 255
	byte %10110011, 255
	byte %10101110, 255
	byte %10110011, 255

	byte %10111101, 255
	byte %10110011, 255
	byte %10100010, 255
	byte %10110011, 255

	byte %10111101, 255
	byte %10110011, %10110011
	byte %10101110, 255
	byte %10110011, 255

	byte %10111101, 255
	byte %10110011, 255
	byte %10100100, %10101110
	byte %10110011, 255

	byte #%00000000, #%00000000, #%00000000, #%00000000


beat1
	byte %00111111, %00111111
	byte 255, 255
	byte %01100000, 255
	byte 255,255

	byte %01100101, 255
	byte 255,255
	byte %01100000, 255
	byte 255,255

	byte %00111111, %00111111
	byte 255, 255
	byte %01111111, 255
	byte 255, 255

	byte %01100101, 255
	byte %01100000, 255
	byte %01100000, %01100000
	byte 255, 255

	byte %11001000, %10001000, %11001100, %10001000

beat2
	byte %00111111, %00111111
	byte 255, 255
	byte %01100000, 255
	byte 255,255

	byte %00111111, %00111111
	byte 255, 255
	byte %01100000, 255
	byte 255,255

	byte %01100101, 255
	byte 255,255
	byte %01100000, 255
	byte 255,255

	byte %00111111, %00111111
	byte 255, 255
	byte %01111111, 255
	byte 255, 255

	byte %11001000, %10001000, %11001100, %10001000


hat
	byte %01100000, 255
	byte 255, 255
	byte %01100000, 255
	byte 255, 255

	byte %01100000, 255
	byte 255, 255
	byte %01100000, 255
	byte 255, 255

	byte %01100000, 255
	byte %01100000, 255
	byte %01100000, 255
	byte 255, 255

	byte %01100000, 255
	byte 255, 255
	byte %01100000, 255
	byte %01100000, 255

	byte #%00000000, #%00000000, #%00000000, #%00000000



patternMute
	byte 255,255,255,255
	byte 255,255,255,255
	byte 255,255,255,255
	byte 255,255,255,255

	byte 255,255,255,255
	byte 255,255,255,255
	byte 255,255,255,255
	byte 255,255,255,255


