;	org $F800




soundTypeArray
	byte 4,6,7,8
	byte 15,12,1,3



;--------------------------------------------------------------------------
; Tempo
;--------------------------------------------------------------------------
; Generates tempo based on TEMPODELAY
;--------------------------------------------------------------------------
handleTempo

	inc tempoCount
	lda tempoCount
	
	cmp #TEMPODELAY
	bne quitTempo

	lda #0
	sta tempoCount

	ldx beat
	inx
	stx beat
	cpx #32
	bne quitTempo

	inc measure

	lda #0
	sta beat

quitTempo

	rts ; tempo




;--------------------------------------------------------------------------
; Accent Reader
;--------------------------------------------------------------------------
; Each set of pattern data is followed by 4 accept bytes.
; Each bit in order represents the accent (on or off)
; of its corresponding 32nd note.  This function
; returns the attenuation of a note in a pattern.
;
; - temp16 must contain an indirect pointer to the pattern data
; - Y must contain the current 32nd note (beat)
;
; = will return the volume in ACC
;
; changes X,Y,ACC
;--------------------------------------------------------------------------
bitMaskArray
	byte #%10000000
	byte #%01000000
	byte #%00100000
	byte #%00010000
	byte #%00001000
	byte #%00000100
	byte #%00000010
	byte #%00000001

accentReader
	; There are 4 accent bytes.  Get the
	; correct one.
	tya
	pha

	and #%00011000
	lsr
	lsr
	lsr

	; The 4 accent bytes are after the 32 bytes
	; that make up the pattern.
	clc
	adc #32
	tay

	; Now set up a mask for the bit
	pla
	and #%00000111
	tax
	
	lda (temp16L),y
	and bitMaskArray,x
	beq noAccent

	; It's an Accent, so don't attenuate
	lda #15

	rts

noAccent

	; No accent, so use a lower volume
	lda #6

	rts ; accentReader





;--------------------------------------------------------------------------
; Note Player
;--------------------------------------------------------------------------
; Actually plays assigned notes using assigned voices
;--------------------------------------------------------------------------
notePlayer

	; Sound type
	ldx sound1
	ldy sound2
	stx AUDC0
	sty AUDC1

	; Frequency
	ldx note1
	ldy note2
	stx AUDF0
	sty AUDF1

	; Volume
	ldx vol1
	ldy vol2
	stx AUDV0
	sty AUDV1
	
	rts ; notePlayer



;--------------------------------------------------------------------------
; Extract Pattern Data
;--------------------------------------------------------------------------
; Each byte of pattern data contains the frequency and 
; sound type data.  This function separates and decodes them.
;
; The encoding is: the 3 high bits contain the encoded sound
; type and the lower 5 bits contain the freq data.
;
; - ACC must contain pattern byte
;
; = ACC will return the freq
; = X will return the sound type
; 
; changes ACC,X
;--------------------------------------------------------------------------
extractPatternData
	cmp #255
	beq noNote
	
	tax

	; Extract freq data and push it
	and #%00011111
	pha

	txa
	lsr
	lsr
	lsr
	lsr
	lsr
	tax
	
	lda soundTypeArray,x

	tax
	pla

	rts

noNote
	lda #255

	rts ; extractPatternData : other rts





;--------------------------------------------------------------------------
; playPattern
;--------------------------------------------------------------------------
; Plays a pattern
;
; - X should contain the offset in the patternArray of the pattern to play
; - ACC should contain the oscillator to be used (0 or 1)
;
;--------------------------------------------------------------------------
playPattern
	; save osc number
	sta temp

	; Get address of selected pattern
	lda patternArray,x
	sta temp16L
	inx
	lda patternArray,x
	sta temp16H

	; The variable, beat, contains the 32nd note
	; that the beat is currently on.
	ldy beat

	lda (temp16L),y

	jsr extractPatternData

	; Get the osc number again
	ldy temp

	sta note1,y
	stx sound1,y	

	cmp #255
	beq noteOff1

	ldy beat
	jsr accentReader

	; Get the osc number again
	ldy temp
	sta vol1,y
noteOff1

	rts ; playPattern



;--------------------------------------------------------------------------
; songPlayer
;--------------------------------------------------------------------------
; Plays up to two pre-programmed patterns simlutaneously.
;
; Call this once per screen-draw.
;--------------------------------------------------------------------------
songPlayer

	jsr handleTempo

	; set the volume to zero
	ldx #0
	stx vol1
	stx vol2

	ldy measure	
	ldx song1,y

	; Check to see if the end of the song was reached
	cpx #255
	bne notEndOfSong
	
	; Go back to the first measure
	ldy #0
	sty measure
	ldx song1,y

notEndOfSong

	lda #0
	jsr playPattern

	ldy measure	
	ldx song2,y

	lda #1
	jsr playPattern

	jsr notePlayer

	rts ; songPlayer




